@@ -5,12 +5,14 @@ import sys
 from stackifyapm.base import Client
 from stackifyapm.conf import constants
 from stackifyapm.handlers.exceptions import get_exception_context
+from stackifyapm.utils import compat
 from stackifyapm.utils.helper import can_insert_script
 from stackifyapm.utils.helper import get_stackify_header
 from stackifyapm.instrumentation.control import instrument
 from stackifyapm.traces import execution_context
 from stackifyapm.traces import set_transaction_context
 from stackifyapm.utils import get_url_data
+from stackifyapm.utils.helper import get_main_file
 from stackifyapm.utils.helper import get_rum_script_or_none
 
 
@@ -19,25 +21,62 @@ def includeme(config):
     config.scan('stackifyapm.contrib.pyramid')
 
 
-def get_data_from_request(request):
-    return {
-        "headers": dict(**request.headers),
+def get_data_from_request(request, capture_body=False):
+    result = {
         "method": request.method,
         "url": get_url_data(request.url),
     }
 
+    if not capture_body:
+        return result
 
-def get_data_from_response(response=None):
-    return {
+    result["headers"] = dict(**request.headers)
+
+    if request.method in constants.HTTP_WITH_BODY:
+        body = ""
+        if request.content_type == "application/x-www-form-urlencoded":
+            body = compat.multidict_to_dict(request.form)
+        elif request.content_type and request.content_type.startswith("multipart/form-data"):
+            body = compat.multidict_to_dict(request.form)
+        else:
+            try:
+                body = request.text
+            except Exception:
+                pass
+
+        if body:
+            result["body"] = body
+            result["body_size"] = len(body)
+
+    return result
+
+
+def get_data_from_response(response=None, capture_body=False):
+    result = {
         "status_code": response and response.status_int or 500,
     }
 
+    if not capture_body:
+        return result
+
+    if response:
+        result["headers"] = dict(**response.headers)
+        result["body"] = response.text
+        result["body_size"] = len(response.text)
+
+    return result
+
 
 def make_client(registry, **defaults):
+    instrument_all_exclude = registry.settings.get('INSTRUMENT_ALL_EXCLUDE', "")
+    excludes = instrument_all_exclude and instrument_all_exclude.split(',') or []
+    excludes.append(get_main_file())
+
     config = {
         "FRAMEWORK_NAME": "pyramid",
         "FRAMEWORK_VERSION": pkg_resources.get_distribution("pyramid").version,
         "BASE_DIR": os.getcwd(),
+        "INSTRUMENT_ALL_EXCLUDE": ','.join(excludes),
     }
     defaults.update(registry.settings)
 
@@ -93,7 +132,13 @@ class stackifyapm_tween_factory(object):
             route_name = '_'.join(request.request_iface.getName().split('_')[:-1])
             reporting_url = view_class and route_name and "{}#{}".format(view_class, route_name) or view_class or route_name or transaction_name
 
-            set_transaction_context(lambda: get_data_from_request(request), "request")
-            set_transaction_context(lambda: get_data_from_response(response), "response")
+            set_transaction_context(
+                lambda: get_data_from_request(request, capture_body=self.client.config.prefix_enabled),
+                "request",
+            )
+            set_transaction_context(
+                lambda: get_data_from_response(response, capture_body=self.client.config.prefix_enabled),
+                "response",
+            )
             set_transaction_context(reporting_url, "reporting_url")
             self.client.end_transaction(transaction_name)
