@@ -15,7 +15,7 @@ from tests.contrib.django.fixtures.testapp.settings import TEST_SETTINGS
 class GetClientTest(TestCase):
     def setUp(self):
         # mock setup logging so it will not log any traces
-        self.setup_logging = mock.patch('stackifyapm.contrib.django.apps.setup_logging')
+        self.setup_logging = mock.patch('stackifyapm.conf.setup_logging')
         self.setup_logging.start()
 
         if not settings.configured:
