@@ -251,6 +251,7 @@ class RumInjectionTest(TestCase):
         res = self.app.test_client().get('/rum_auto')
         cookies = [header for header in res.headers if header[0] == 'Set-Cookie' and RUM_COOKIE_NAME in header[1]]
 
+        assert "Path=/" in cookies[0][1]
         assert any(cookies)
 
     @mock.patch('stackifyapm.base.Client.queue')
@@ -320,12 +321,12 @@ class TestPrefixInstrumentation(TestCase):
         assert queue_mock.called
         transaction_dict = queue_mock.call_args_list[0][0][0].to_dict()
 
-        assert '{"result":"index"}' in transaction_dict.get('props', {}).get('RESPONSE_BODY')
-        assert '19' == transaction_dict.get('props', {}).get('RESPONSE_SIZE_BYTES')
-        assert 'application/json' in transaction_dict.get('props', {}).get('RESPONSE_HEADERS')
-        assert '{"foo": "bar"}' == transaction_dict.get('props', {}).get('REQUEST_BODY')
-        assert '14' == transaction_dict.get('props', {}).get('REQUEST_SIZE_BYTES')
-        assert 'x-test' in transaction_dict.get('props', {}).get('REQUEST_HEADERS')
+        assert '{"result":"index"}' in transaction_dict.get('props', {}).get('PREFIX_RESPONSE_BODY')
+        assert '19' == transaction_dict.get('props', {}).get('PREFIX_RESPONSE_SIZE_BYTES')
+        assert 'application/json' in transaction_dict.get('props', {}).get('PREFIX_RESPONSE_HEADERS')
+        assert '{"foo": "bar"}' == transaction_dict.get('props', {}).get('PREFIX_REQUEST_BODY')
+        assert '14' == transaction_dict.get('props', {}).get('PREFIX_REQUEST_SIZE_BYTES')
+        assert 'x-test' in transaction_dict.get('props', {}).get('PREFIX_REQUEST_HEADERS')
 
     @mock.patch('stackifyapm.base.Client.queue')
     @mock.patch('stackifyapm.base.Client.get_property_info')
@@ -338,12 +339,12 @@ class TestPrefixInstrumentation(TestCase):
         assert queue_mock.called
         transaction_dict = queue_mock.call_args_list[0][0][0].to_dict()
 
-        assert not transaction_dict.get('props', {}).get('RESPONSE_BODY')
-        assert not transaction_dict.get('props', {}).get('RESPONSE_SIZE_BYTES')
-        assert not transaction_dict.get('props', {}).get('RESPONSE_HEADERS')
-        assert '{"foo": "bar"}' == transaction_dict.get('props', {}).get('REQUEST_BODY')
-        assert '14' == transaction_dict.get('props', {}).get('REQUEST_SIZE_BYTES')
-        assert 'x-test' in transaction_dict.get('props', {}).get('REQUEST_HEADERS')
+        assert not transaction_dict.get('props', {}).get('PREFIX_RESPONSE_BODY')
+        assert not transaction_dict.get('props', {}).get('PREFIX_RESPONSE_SIZE_BYTES')
+        assert not transaction_dict.get('props', {}).get('PREFIX_RESPONSE_HEADERS')
+        assert '{"foo": "bar"}' == transaction_dict.get('props', {}).get('PREFIX_REQUEST_BODY')
+        assert '14' == transaction_dict.get('props', {}).get('PREFIX_REQUEST_SIZE_BYTES')
+        assert 'x-test' in transaction_dict.get('props', {}).get('PREFIX_REQUEST_HEADERS')
 
     @mock.patch('stackifyapm.base.Client.queue')
     @mock.patch('stackifyapm.base.Client.get_property_info')
@@ -356,9 +357,9 @@ class TestPrefixInstrumentation(TestCase):
         assert queue_mock.called
         transaction_dict = queue_mock.call_args_list[0][0][0].to_dict()
 
-        assert '<html><head>Test</head></html>' in transaction_dict.get('props', {}).get('RESPONSE_BODY')
-        assert '30' == transaction_dict.get('props', {}).get('RESPONSE_SIZE_BYTES')
-        assert 'text/html' in transaction_dict.get('props', {}).get('RESPONSE_HEADERS')
-        assert '{"foo": "bar"}' == transaction_dict.get('props', {}).get('REQUEST_BODY')
-        assert '14' == transaction_dict.get('props', {}).get('REQUEST_SIZE_BYTES')
-        assert 'x-test' in transaction_dict.get('props', {}).get('REQUEST_HEADERS')
+        assert '<html><head>Test</head></html>' in transaction_dict.get('props', {}).get('PREFIX_RESPONSE_BODY')
+        assert '30' == transaction_dict.get('props', {}).get('PREFIX_RESPONSE_SIZE_BYTES')
+        assert 'text/html' in transaction_dict.get('props', {}).get('PREFIX_RESPONSE_HEADERS')
+        assert '{"foo": "bar"}' == transaction_dict.get('props', {}).get('PREFIX_REQUEST_BODY')
+        assert '14' == transaction_dict.get('props', {}).get('PREFIX_REQUEST_SIZE_BYTES')
+        assert 'x-test' in transaction_dict.get('props', {}).get('PREFIX_REQUEST_HEADERS')
